@@ -14,7 +14,7 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **HEAD** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param params: request parameters
         :type params: dict
         :param headers: request headers
@@ -31,7 +31,7 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **GET** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param params: request parameters
         :type params: dict
         :param headers: request headers
@@ -48,9 +48,9 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **PUT** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param data: request payload
-        :type data: str | dict
+        :type data: str | unicode | dict
         :param params: request parameters
         :type params: dict
         :param headers: request headers
@@ -67,9 +67,9 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **POST** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param data: request payload
-        :type data: str | dict
+        :type data: str | unicode | dict
         :param params: request parameters
         :type params: dict
         :param headers: request headers
@@ -86,9 +86,9 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **PATCH** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param data: request payload
-        :type data: str | dict
+        :type data: str | unicode | dict
         :param params: request parameters
         :type params: dict
         :param headers: request headers
@@ -105,9 +105,9 @@ class BaseHTTPClient(object):  # pragma: no cover
         """Execute an HTTP **DELETE** method.
 
         :param url: request URL
-        :type url: str
+        :type url: str | unicode
         :param data: request payload
-        :type data: str | dict
+        :type data: str | unicode | dict
         :param params: request parameters
         :type params: dict
         :param headers: request headers
